@@ -17,7 +17,12 @@ import aws_solutions_constructs.aws_cloudfront_apigateway._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-cloudfront-apigateway-lambda", "1.46.0", __name__[0:-6], "aws-cloudfront-apigateway-lambda@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-cloudfront-apigateway-lambda",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-cloudfront-apigateway-lambda@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
